{# -*- engine:django -*- #}

{% extends "core/base.html" %}

{% load i18n material_form %}
{% load render_table from django_tables2 %}

{% block browser_title %}{% blocktrans %}Groups{% endblocktrans %}{% endblock %}
{% block page_title %}{% blocktrans %}Groups{% endblocktrans %}{% endblock %}

{% block content %}
  <a class="btn green waves-effect waves-light" href="{% url 'create_group' %}">
    <i class="material-icons iconify left" data-icon="mdi:add"></i>
    {% trans "Create group" %}
  </a>

  <h2>{% trans "Filter groups" %}</h2>
  <form method="get">
    {% form form=groups_filter.form %}{% endform %}
    {% trans "Search" as caption %}
    {% include "core/partials/save_button.html" with caption=caption icon="search" %}
    <button type="reset" class="btn red waves-effect waves-light">
      <i class="material-icons iconify left" data-icon="mdi:close"></i>
      {% trans "Clear" %}
    </button>
  </form>

  <h2>{% trans "Selected groups" %}</h2>
  {% render_table groups_table %}
{% endblock %}
