{# -*- engine:django -*- #}

{% extends "core/base.html" %}

{% load i18n %}
{% load render_table from django_tables2 %}

{% block browser_title %}{% blocktrans %}School terms{% endblocktrans %}{% endblock %}
{% block page_title %}{% blocktrans %}School terms{% endblocktrans %}{% endblock %}

{% block content %}
  <a class="btn green waves-effect waves-light" href="{% url 'create_school_term' %}">
    <i class="material-icons left iconify" data-icon="mdi:add"></i>
    {% trans "Create school term" %}
  </a>

  {% render_table table %}
{% endblock %}
