# Generated by Django 3.2.12 on 2022-02-18 21:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0035_preference_model_unique'),
    ]

    operations = [
        migrations.AddField(
            model_name='additionalfield',
            name='help_text',
            field=models.TextField(blank=True, verbose_name='Help text / description'),
        ),
        migrations.AddField(
            model_name='additionalfield',
            name='required',
            field=models.BooleanField(default=False, verbose_name='Required'),
        ),
    ]
