# Generated by Django 3.2.8 on 2021-11-04 19:35

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('core', '0024_oauth_grant_types_optional'),
    ]

    operations = [
        migrations.AlterField(
            model_name='oauthaccesstoken',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='core_oauthaccesstoken', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='oauthapplication',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='core_oauthapplication', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='oauthgrant',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='core_oauthgrant', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='oauthidtoken',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='core_oauthidtoken', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='oauthrefreshtoken',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='core_oauthrefreshtoken', to=settings.AUTH_USER_MODEL),
        ),
    ]
