<button type="button" data-target="{{ target }}"
        class="{{ classes }} copy-button waves-effect waves-secondary">
  <i class="material-icons iconify copy-icon-copy" data-icon="mdi:content-copy"></i>
  <i class="material-icons iconify copy-icon-success" style="display: none" data-icon="mdi:check"></i>
</button>
