{
  accessTokens: oauthAccessTokens {
    id
    created
    updated
    expires
    scopes {
      name
      description
    }
    application {
      id
      name
      icon {
        absoluteUrl
      }
    }
  }
}
