# Generated by Django 3.2.9 on 2021-12-09 14:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0032_remove_person_is_active'),
    ]

    operations = [
        migrations.AddField(
            model_name='group',
            name='avatar',
            field=models.ImageField(blank=True, help_text='This is a picture or an avatar for public display.', null=True, upload_to='', verbose_name='Display picture / Avatar'),
        ),
        migrations.AddField(
            model_name='group',
            name='photo',
            field=models.ImageField(blank=True, help_text='This is an official photo, used for official documents and for internal use cases.', null=True, upload_to='', verbose_name='Photo'),
        ),
        migrations.AddField(
            model_name='person',
            name='avatar',
            field=models.ImageField(blank=True, help_text='This is a picture or an avatar for public display.', null=True, upload_to='', verbose_name='Display picture / Avatar'),
        ),
        migrations.AlterField(
            model_name='person',
            name='photo',
            field=models.ImageField(blank=True, help_text='This is an official photo, used for official documents and for internal use cases.', null=True, upload_to='', verbose_name='Photo'),
        ),
        migrations.AlterModelOptions(
            name='globalpermissions',
            options={'default_permissions': (), 'managed': False, 'permissions': (('view_system_status', 'Can view system status'), ('manage_data', 'Can manage data'), ('impersonate', 'Can impersonate'), ('search', 'Can use search'), ('change_site_preferences', 'Can change site preferences'), ('change_person_preferences', 'Can change person preferences'), ('change_group_preferences', 'Can change group preferences'), ('test_pdf', 'Can test PDF generation'))},
        ),
        migrations.AlterModelOptions(
            name='person',
            options={'ordering': ['last_name', 'first_name'], 'permissions': (('view_address', 'Can view address'), ('view_contact_details', 'Can view contact details'), ('view_photo', 'Can view photo'), ('view_avatar', 'Can view avatar image'), ('view_person_groups', 'Can view persons groups'), ('view_personal_details', 'Can view personal details')), 'verbose_name': 'Person', 'verbose_name_plural': 'Persons'},
        ),
    ]
