# Generated by Django 3.2.12 on 2022-02-20 21:04

from django.db import migrations, models
import django.db.models.deletion
import uuid



class Migration(migrations.Migration):

    dependencies = [
        ('core', '0038_notification_send_at'),
    ]

    operations = [
        migrations.CreateModel(
            name='PersonalICalUrl',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('uuid', models.UUIDField(default=uuid.uuid4, editable=False, unique=True, verbose_name='UUID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('person', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='calendar_urls', to='core.person', verbose_name='Person')),
            ],
            options={
                'verbose_name': 'Personal Calendar URL',
                'verbose_name_plural': 'Personal Calendar URLs',
            },
        ),
    ]
