# Generated by Django 3.2.12 on 2022-02-23 19:33

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0037_add_static_content_widget'),
    ]

    operations = [
        migrations.AddField(
            model_name='notification',
            name='send_at',
            field=models.DateTimeField(default=django.utils.timezone.now, verbose_name='Send notification at'),
            preserve_default=False,
        ),
    ]
