query whoAmI($permissions: [String]!) {
  whoAmI {
    username
    isAuthenticated
    isAnonymous
    isImpersonate
    person {
      photo {
        url
      }
      fullName
      avatarUrl
      isDummy
    }
    permissions: globalPermissionsByName(permissions: $permissions) {
      name
      result
    }
  }
}
