{% extends "core/base.html" %}

{% load i18n material_form %}

{% block browser_title %}{% blocktrans %}Register OAuth2 Application{% endblocktrans %}{% endblock %}
{% block page_title %}{% blocktrans %}Register OAuth2 Application{% endblocktrans %}{% endblock %}

{% block content %}
  <form method="post" enctype="multipart/form-data">
    {% csrf_token %}
    {% form form=form %}{% endform %}
    {% include "core/partials/save_button.html" %}
    <a class="btn waves-effect red waves-light" href="{% url "oauth2_applications" %}">
      <i class="material-icons iconify left" data-icon="mdi:close"></i> {% trans "Cancel" %}
    </a>
  </form>
{% endblock %}
