# Generated by Django 3.2.16 on 2022-11-02 19:35

import django.utils.timezone
from django.db import migrations, models

import oauth2_provider.generators
import oauth2_provider.models


class Migration(migrations.Migration):

    dependencies = [
        ("core", "0043_task_assignment_meta"),
    ]

    operations = [
        migrations.AddField(
            model_name="taskuserassignment",
            name="result_fetched",
            field=models.BooleanField(default=False, verbose_name="Result fetched"),
        ),
    ]
