# Generated by Django 4.2.13 on 2024-05-22 08:49

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('core', '0049_oauthapplication_post_logout_redirect_uris'),
    ]

    operations = [
        migrations.AddField(
            model_name='oauthapplication',
            name='allowed_origins',
            field=models.TextField(blank=True, default='', help_text='Allowed origins list to enable CORS, space separated'),
        ),
        migrations.AddField(
            model_name='oauthapplication',
            name='hash_client_secret',
            field=models.BooleanField(default=True),
        ),
        migrations.AlterField(
            model_name='oauthaccesstoken',
            name='token',
            field=models.CharField(db_index=True, max_length=255, unique=True),
        ),
        migrations.AlterField(
            model_name='oauthapplication',
            name='post_logout_redirect_uris',
            field=models.TextField(blank=True, default='', help_text='Allowed Post Logout URIs list, space separated'),
        ),
    ]
