query person($id: ID) {
  object: personByIdOrMe(id: $id) {
    id
    username
    firstName
    additionalName
    lastName
    fullName

    description

    sex
    street
    housenumber
    postalCode
    place
    phoneNumber
    mobileNumber
    email
    dateOfBirth
    placeOfBirth

    secondaryImageUrl

    guardians {
      id
      fullName
    }
    children {
      id
      fullName
    }
    memberOf {
      id
      name
      schoolTerm {
        name
      }
    }
    ownerOf {
      id
      name
      schoolTerm {
        name
      }
    }
  }
}
